import React from 'react';

import { useMutation, gql } from "@apollo/client";
import { GraphQLID } from 'graphql';

const ListAnnonceItem = ({annonce}) => {

    const DELETE_ANNONCE_MUTATION = gql`
        mutation deleteAnnonce($annonceId: ID!) {
            deleteAnnonce(annonceId: $annonceId) {
                _id
                title
                type
                status
                published
                price
                description
                availabilityDate
                assessments {
                _id
                text
                }
            }
        }
    `;

    const onClick = (annonceId) => {
        const id = GraphQLID.parseValue(annonceId);
        deleteAnnonce({ variables: { annonceId: id } });        
    }   

    const [deleteAnnonce, { 
        loading: mutationLoading,
        error: mutationError,
        data 
    }] = useMutation(DELETE_ANNONCE_MUTATION);

    if (mutationLoading) return 'Loading...';
    if (mutationError) return `Error! ${mutationError.message}`;

    return (
        <li>
            <img src="img.jpeg"/>
            <h3>{annonce.title}</h3>
            <button onClick={e => onClick(annonce._id)}>X</button>
        </li>
    )
        
}

export default ListAnnonceItem